package com.ruoyi.frequency.klkaccount.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.frequency.klkaccount.mapper.KlkAccountMapper;
import com.ruoyi.frequency.klkaccount.entity.KlkAccount;
import com.ruoyi.frequency.klkaccount.service.KlkAccountService;

/**
 * 拉卡拉平台账号信息Service业务层处理
 *
 * @author liwenlong
 * @date 2024-05-07
 */
@Service
public class KlkAccountServiceImpl extends ServiceImpl<KlkAccountMapper, KlkAccount>  implements KlkAccountService
{
    @Autowired
    private KlkAccountMapper klkAccountMapper;

    /**
     * 查询拉卡拉平台账号信息
     *
     * @param id 拉卡拉平台账号信息主键
     * @return 拉卡拉平台账号信息
     */
    @Override
    public KlkAccount selectKlkAccountById(Long id)
    {
        return klkAccountMapper.selectKlkAccountById(id);
    }

    /**
     * 查询拉卡拉平台账号信息列表
     *
     * @param klkAccount 拉卡拉平台账号信息
     * @return 拉卡拉平台账号信息
     */
    @Override
    public List<KlkAccount> selectKlkAccountList(KlkAccount klkAccount)
    {
        return klkAccountMapper.selectKlkAccountList(klkAccount);
    }

    /**
     * 新增拉卡拉平台账号信息
     *
     * @param klkAccount 拉卡拉平台账号信息
     * @return 结果
     */
    @Override
    public int insertKlkAccount(KlkAccount klkAccount)
    {
        klkAccount.setCreateData();
        return klkAccountMapper.insert(klkAccount);
    }

    /**
     * 修改拉卡拉平台账号信息
     *
     * @param klkAccount 拉卡拉平台账号信息
     * @return 结果
     */
    @Override
    public int updateKlkAccount(KlkAccount klkAccount)
    {
        klkAccount.setUpdateData();
        return klkAccountMapper.updateKlkAccount(klkAccount);
    }

    /**
     * 批量删除拉卡拉平台账号信息
     *
     * @param ids 需要删除的拉卡拉平台账号信息主键
     * @return 结果
     */
    @Override
    public int deleteKlkAccountByIds(Long[] ids,Integer delFlag)
    {
        this.lambdaUpdate().set(KlkAccount::getDelFlag,delFlag).in(KlkAccount::getId,ids).update();
        return ids.length;
    }

}
